<footer class="footer container-fluid bg-medux">
  <div class="row">
    <div class="col-md-4">
      left part
    </div>
    <div class="col-md-4">
      middle part
    </div>
    <div class="col-md-4">
      right part
    </div>
  </div>
</footer>
