{% load static i18n unicorn %}
<!DOCTYPE html>
<html lang="en">
<head>
  <meta name="description" content="">
  <meta name="keywords" content="">
  <meta name="author" content="">
  <meta charset="UTF-8"/>
  <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1"/>
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <meta
      content='width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0, shrink-to-fit=no'
      name='viewport'/>
  {% block extra_head %}{% endblock %}
  {% unicorn_scripts %}

  <title>{% block title %}MedUX{% endblock %}</title>

  {#    Bootstrap icons #}
  {#    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.3.0/font/bootstrap-icons.css">#}

  <link rel="icon" type="image/png" href="{% static 'img/favicon.ico' %}">
  {#  <link rel="apple-touch-icon" sizes="76x76" href={% static "assets/img/apple-icon.png" %}>#}

  {#    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600;700;800&display=swap" rel="stylesheet"/>#}
  {#  FIXME: include icons and fonts locally #}
  {#  FIXME: use minified version #}
  <link
      href="https://cdn.jsdelivr.net/npm/bootstrap@5.0.0-beta2/dist/css/bootstrap.min.css"
      rel="stylesheet"
      integrity="sha384-BmbxuPwQa2lc/FVzBcNJ7UAyJxM6wuqIj61tLrc4wSX0szH/Ev+nYRRuWlolflfl"
      crossorigin="anonymous">

  {#  <link href="{% static 'css/bootstrap.css' %}" rel="stylesheet">#}
  {#  minified: integrity="sha384-giJF6kkoqNQ00vy+HMDP7azOuL0xtbfIcaT9wjKHr8RbDVddVHyTfAAsrekwKmP1" crossorigin="anonymous"#}


  <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.4.0/font/bootstrap-icons.css">

  {#    <link rel="stylesheet" href="{% static 'css/styles.css' %}" />#}
  <link rel="stylesheet" href="{% static 'css/medux.css' %}"/>
  {% block stylesheets %}{% endblock %}
</head>
<body class="bg-light d-flex flex-column min-vh-100">
{% csrf_token %}
{% block body %}{% endblock %}
{% block footer %}{% endblock %}
{% include 'includes/scripts.html' %}
{% block javascripts %}{% endblock %}
</body>
</html>
