{% load static %}

{#<!-- AlpineJs -->#}
{#<script src="https://cdn.jsdelivr.net/gh/alpinejs/alpine@v2.x.x/dist/alpine.min.js" defer></script>#}
{#<script src="{% static 'js/init-alpine.js' %}"></script>#}

<!-- Bootstrap -->
{# FIXME: license #}
<script src="{% static 'core/js/bootstrap.js' %}"></script>

{#<script#}
{#    src="https://cdn.jsdelivr.net/npm/bootstrap@5.0.0-beta2/dist/js/bootstrap.bundle.min.js"#}
{#    integrity="sha384-b5kHyXgcpbZJO/tY9Ul7kGkf1S0CWuKcCD38l8YkeH8z8QjE0GmW1gYU5S9FOnJ0"#}
{#    crossorigin="anonymous"></script>#}

<!-- additional libs -->
{# FIXME: license #}
<script src="https://cdn.jsdelivr.net/npm/chart.js@2.9.4/dist/Chart.min.js"
        integrity="sha384-zNy6FEbO50N+Cg5wap8IKA4M/ZnLJgzc6w2NqACZaK0u0FXfOWRRJOnQtpZun8ha"
        crossorigin="anonymous"></script>

{#<script src="{% static 'js/dashboard.js' %}"></script>#}

<script type="text/javascript" src="{% static 'js/core.js' %}"></script>
{#<script src="{% static 'core_controller.js' %}"></script>#}

{# here, all global Js files from plugins get loaded #}

<!-- global plugin's javascripts -->
{% for js_url in global_javascripts %}
  <script src="{% static js_url.file %}"></script>
{% endfor %}

