{% extends 'layouts/empty.html' %}
{% load static %}
{% load i18n %}
{% block title %}{% trans "Error" %}{% endblock %}

{% block content %}
  <div class="container">
    <div class="row">
      <div class="col-md-4 col-offset-md-4">
        <h1>404</h1>
        <div class="alert alert-warning">
          {% trans 'This page could not be found.' %}
        </div>
      </div>
    </div>
  </div>
{% endblock content %}